import axios from 'axios'
import router from '../router/index.js'

import {
    Notification,
    MessageBox,
    Message
} from 'element-ui'

//axios.defaults.headers['Content-Type'] = 'application/json;charset=utf-8'
let baseURL = '/admin';

// 创建axios实例
const service = axios.create({
    // axios中请求配置有baseURL选项，表示请求URL公共部分
    baseURL: baseURL,
    // 超时
    timeout: 10000
})


// request拦截器
service.interceptors.request.use(config => {
    //获取token
    var token = localStorage.getItem('auth-token')
    // 让每个请求携带自定义token 请根据实际情况自行修改
    config.headers['ht-token'] = token;
    return config
}, error => {
    console.log(error)
    Promise.reject(error)
})


// 响应拦截器
service.interceptors.response.use(res => {
        // 未设置状态码则默认成功状态
        const code = res.data.code;
        // 获取错误信息
        const msg = res.data.msg;
        if (code === 401) {
            MessageBox.confirm('登录状态已过期，您可以继续留在该页面，或者重新登录', '系统提示', {
                confirmButtonText: '重新登录',
                cancelButtonText: '取消',
                type: 'warning'
            }).then(() => {
                router.replace('/login')
            }).catch(() => {
            });
            return Promise.reject('令牌验证失败')
        } else if (code === 500) {
            Message({
                message: msg,
                type: 'error'
            })
            return Promise.reject(new Error(msg))
        } else if (code !== 0) {
            Notification.error({
                title: msg
            })
            return Promise.reject('error')
        } else {
            return Promise.resolve(res.data)
        }
    },
    error => {
        console.log('err' + error)
        let {
            message
        } = error;
        if (message == "Network Error") {
            message = "后端接口连接异常";
        } else if (message.includes("timeout")) {
            message = "系统接口请求超时";
        } else if (message.includes("Request failed with status code")) {
            message = "系统接口" + message.substr(message.length - 3) + "异常";
        }
        Message({
            message: message,
            type: 'error',
            duration: 5 * 1000
        })
        return Promise.reject(error)
    }
)

export default service
